@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2018 NVIDIA Corporation
+    Copyright (c) 2018-2019 NVIDIA Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -185,7 +185,7 @@ static uvm_gpu_t *get_gpu_from_node_id(uvm_va_space_t *va_space, int node_id)
 {
     uvm_gpu_t *gpu;
 
-    for_each_gpu_in_mask(gpu, &va_space->registered_gpus) {
+    for_each_va_space_gpu(gpu, va_space) {
         if (uvm_gpu_numa_info(gpu)->node_id == node_id)
             return gpu;
     }
