@@ -517,6 +517,23 @@ NV_STATUS uvm_api_clean_up_zombie_resources(UVM_CLEAN_UP_ZOMBIE_RESOURCES_PARAMS
     return NV_OK;
 }
 
+NV_STATUS uvm_api_validate_va_range(UVM_VALIDATE_VA_RANGE_PARAMS *params, struct file *filp)
+{
+    NV_STATUS status = NV_ERR_INVALID_ADDRESS;
+    uvm_va_space_t *va_space = uvm_va_space_get(filp);
+    uvm_va_range_t *va_range;
+
+    uvm_va_space_down_read(va_space);
+
+    va_range = uvm_va_range_find(va_space, params->base);
+    if (va_range && va_range->node.start == params->base && va_range->node.end + 1 == params->base + params->length)
+        status = NV_OK;
+
+    uvm_va_space_up_read(va_space);
+
+    return status;
+}
+
 static NV_STATUS uvm_va_range_add_gpu_va_space_managed(uvm_va_range_t *va_range, uvm_gpu_va_space_t *gpu_va_space)
 {
     uvm_va_space_t *va_space = va_range->va_space;
